if (!require ("stats", quietly=TRUE))
    stop("package", sQuote("stats"), "is needed.  Stopping")
tcm1y <- ts(c(
 2.36
,2.48
,2.45
,2.38
,2.28
,2.20
,1.79
,1.67
,1.66
,1.41
,1.14
,1.13
,0.96
,0.85
,0.82
,0.84
,0.88
,1.03
,1.17
,1.14
,1.21
,1.39
,1.57
,1.59
,1.75
,1.90
,1.91
,2.02
,2.37
,2.36
,2.39
,2.48
,2.73
,2.58
,2.49
,2.61
,2.92
,2.94
,2.74
,2.76
,3.10
,3.35
,3.28
,3.44
,3.68
,3.37
,3.38
,3.42
,3.49
,3.48
,3.65
,3.81
,4.01
,4.07
,4.01
,3.57
,3.18
,2.65
,1.99
,1.84
,1.45
,1.37
,1.23
,1.61
,2.50
,3.05
,3.19
,3.10
,3.29
,3.36
,3.54
,3.61
,3.72
,3.96
,4.07
,4.39
,4.42
,5.00
,4.80
,4.81
,5.14
,5.03
,4.66
,4.02
,4.04
,4.21
,3.36
,3.20
,2.95
,3.07
,3.04
,3.08
,2.86
,2.81
,2.93
,2.88
,2.88
,2.87
,3.06
,2.92
,3.06
,3.06
,3.05
,3.07
,3.18
,3.28
,3.28
,3.06
,2.99
,3.03
,3.03
,3.29
,3.20
,3.06
,2.98
,3.00
,3.01
,3.04
,3.01
,3.03
,3.11
,3.12
,3.20
,3.48
,3.53
,3.57
,3.64
,3.74
,3.81
,3.79
,3.78
,3.91
,3.91
,3.84
,3.83
,3.72
,3.74
,3.84
,3.86
,3.91
,4.02
,3.94
,4.03
,4.06
,4.04
,4.03
,3.99
,3.98
,4.07
,4.20
,4.30
,4.37
,4.72
,4.88
,4.94
,4.97
,4.90
,4.93
,4.97
,5.17
,5.54
,5.82
,5.58
,5.54
,5.20
,4.75
,4.71
,4.35
,4.11
,4.15
,4.48
,5.01
,5.13
,5.24
,5.37
,5.61
,5.71
,5.43
,5.41
,5.58
,5.71
,6.14
,5.98
,5.65
,5.43
,5.45
,5.57
,5.75
,6.19
,6.34
,6.41
,6.34
,6.26
,6.42
,7.04
,7.60
,7.54
,7.82
,7.64
,7.89
,8.17
,8.10
,7.59
,6.97
,7.06
,7.75
,7.55
,7.10
,6.98
,6.73
,6.43
,5.51
,5.00
,4.57
,3.89
,3.69
,4.30
,5.04
,5.64
,6.04
,5.80
,5.41
,4.91
,4.67
,4.60
,4.28
,4.27
,4.67
,4.96
,4.64
,4.93
,4.96
,4.98
,5.52
,5.52
,5.27
,5.52
,5.89
,6.19
,6.85
,6.85
,6.89
,7.31
,8.39
,8.82
,8.31
,7.40
,7.57
,7.27
,7.42
,6.88
,7.76
,8.62
,8.78
,8.67
,8.80
,9.36
,8.87
,8.05
,7.66
,7.31
,6.83
,5.98
,6.11
,6.90
,6.39
,6.29
,7.11
,7.70
,7.75
,6.95
,6.49
,6.60
,5.81
,5.91
,6.21
,5.92
,6.40
,6.52
,6.20
,6.00
,5.84
,5.50
,5.29
,4.89
,5.29
,5.47
,5.50
,5.44
,5.84
,5.80
,5.94
,6.37
,6.53
,6.97
,6.95
,6.96
,7.28
,7.34
,7.31
,7.45
,7.82
,8.09
,8.39
,8.31
,8.64
,9.14
,10.01
,10.30
,10.41
,10.24
,10.25
,10.12
,10.12
,9.57
,9.64
,9.98
,10.84
,12.44
,12.39
,11.98
,12.06
,13.92
,15.82
,13.30
,9.39
,8.16
,8.65
,10.24
,11.52
,12.49
,14.15
,14.88
,14.08
,14.57
,13.71
,14.32
,16.20
,14.86
,15.72
,16.72
,16.52
,15.38
,12.41
,12.85
,14.32
,14.73
,13.95
,13.98
,13.34
,14.07
,13.24
,11.43
,10.85
,9.32
,9.16
,8.91
,8.62
,8.92
,9.04
,8.98
,8.90
,9.66
,10.20
,10.53
,10.16
,9.81
,9.94
,10.11
,9.90
,10.04
,10.59
,10.90
,11.66
,12.08
,12.03
,11.82
,11.58
,10.90
,9.82
,9.33
,9.02
,9.29
,9.86
,9.14
,8.46
,7.80
,7.86
,8.05
,8.07
,8.01
,7.88
,7.67
,7.73
,7.61
,7.03
,6.44
,6.65
,6.73
,6.27
,5.93
,5.77
,5.72
,5.80
,5.87
,5.78
,5.96
,6.03
,6.50
,7.00
,6.80
,6.68
,7.03
,7.67
,7.59
,6.96
,7.17
,6.99
,6.64
,6.71
,7.01
,7.40
,7.49
,7.75
,8.17
,8.09
,8.11
,8.48
,8.99
,9.05
,9.25
,9.57
,9.36
,8.98
,8.44
,7.89
,8.18
,8.22
,7.99
,7.77
,7.72
,7.92
,8.11
,8.35
,8.40
,8.32
,8.10
,7.94
,7.78
,7.76
,7.55
,7.31
,7.05
,6.64
,6.27
,6.40
,6.24
,6.13
,6.36
,6.31
,5.78
,5.57
,5.33
,4.89
,4.38
,4.15
,4.29
,4.63
,4.30
,4.19
,4.17
,3.60
,3.47
,3.18
,3.30
,3.68
,3.71
,3.50
,3.39
,3.33
,3.24
,3.36
,3.54
,3.47
,3.44
,3.36
,3.39
,3.58
,3.61
,3.54
,3.87
,4.32
,4.82
,5.31
,5.27
,5.48
,5.56
,5.76
,6.11
,6.54
,7.14
,7.05
,6.70
,6.43
,6.27
,6.00
,5.64
,5.59
,5.75
,5.62
,5.59
,5.43
,5.31
,5.09
,4.94
,5.34
,5.54
,5.64
,5.81
,5.85
,5.67
,5.83
,5.55
,5.42
,5.47
,5.61
,5.53
,5.80
,5.99
,5.87
,5.69
,5.54
,5.56
,5.52
,5.46
,5.46
,5.53
,5.24
,5.31
,5.39
,5.38
,5.44
,5.41
,5.36
,5.21
,4.71
,4.12
,4.53
,4.52
,4.51
,4.70
,4.78
,4.69
,4.85
,5.10
,5.03
,5.20
,5.25),
start=c(1953,4), end=c(1999,9), frequency=12)
tcm3y <- ts(c(        
 2.51
,2.72
,2.74
,2.62
,2.58
,2.56
,2.23
,2.20
,2.07
,1.89
,1.63
,1.59
,1.54
,1.56
,1.53
,1.47
,1.49
,1.60
,1.72
,1.75
,1.81
,1.99
,2.12
,2.26
,2.37
,2.37
,2.39
,2.51
,2.72
,2.69
,2.62
,2.73
,2.88
,2.78
,2.67
,2.89
,3.19
,3.08
,2.95
,3.06
,3.39
,3.50
,3.40
,3.57
,3.76
,3.46
,3.42
,3.47
,3.53
,3.61
,3.80
,3.96
,4.02
,4.06
,4.09
,3.70
,3.11
,2.78
,2.58
,2.40
,2.15
,2.07
,2.08
,2.42
,3.06
,3.52
,3.67
,3.60
,3.72
,3.91
,3.92
,3.97
,4.03
,4.25
,4.52
,4.60
,4.60
,4.97
,4.78
,4.85
,5.12
,4.99
,4.73
,4.29
,4.27
,4.46
,4.01
,3.63
,3.41
,3.43
,3.53
,3.60
,3.42
,3.39
,3.46
,3.35
,3.33
,3.23
,3.63
,3.59
,3.76
,3.73
,3.62
,3.61
,3.72
,3.76
,3.69
,3.45
,3.38
,3.40
,3.39
,3.62
,3.46
,3.41
,3.33
,3.40
,3.37
,3.40
,3.39
,3.41
,3.50
,3.54
,3.61
,3.76
,3.77
,3.82
,3.87
,3.95
,4.01
,4.04
,4.00
,4.12
,4.15
,4.04
,4.01
,3.93
,3.93
,4.01
,4.02
,4.04
,4.08
,4.03
,4.08
,4.13
,4.12
,4.11
,4.08
,4.09
,4.16
,4.24
,4.33
,4.45
,4.79
,4.90
,5.02
,4.97
,4.89
,5.00
,5.05
,5.26
,5.68
,5.79
,5.48
,5.53
,5.19
,4.75
,4.73
,4.47
,4.38
,4.61
,4.89
,5.06
,5.23
,5.41
,5.52
,5.71
,5.71
,5.53
,5.61
,5.80
,5.75
,6.11
,5.82
,5.54
,5.42
,5.39
,5.52
,5.57
,6.16
,6.22
,6.32
,6.38
,6.25
,6.51
,6.83
,7.31
,7.29
,7.77
,7.57
,7.65
,8.10
,8.24
,7.79
,7.15
,7.39
,7.94
,7.84
,7.56
,7.46
,7.11
,6.96
,6.25
,5.75
,5.61
,5.07
,4.50
,5.22
,5.97
,6.32
,6.74
,6.35
,5.89
,5.56
,5.35
,5.27
,5.14
,5.25
,5.56
,5.88
,5.55
,5.64
,5.78
,5.79
,6.06
,6.05
,5.94
,6.01
,6.27
,6.58
,6.86
,6.78
,6.83
,6.84
,7.54
,7.89
,7.25
,6.81
,7.00
,6.81
,6.96
,6.76
,7.35
,8.05
,8.27
,8.15
,8.41
,8.66
,8.41
,8.00
,7.61
,7.24
,7.23
,6.65
,6.81
,7.76
,7.39
,7.17
,7.72
,8.16
,8.29
,7.81
,7.46
,7.43
,6.99
,7.06
,7.13
,6.84
,7.27
,7.31
,7.12
,6.86
,6.66
,6.24
,6.09
,5.68
,6.22
,6.44
,6.47
,6.31
,6.55
,6.39
,6.51
,6.79
,6.84
,7.19
,7.22
,7.30
,7.61
,7.67
,7.70
,7.85
,8.07
,8.30
,8.54
,8.33
,8.41
,8.62
,9.04
,9.33
,9.50
,9.29
,9.38
,9.43
,9.42
,8.95
,8.94
,9.14
,9.69
,10.95
,11.18
,10.71
,10.88
,12.84
,14.05
,12.02
,9.44
,8.91
,9.27
,10.63
,11.57
,12.01
,13.31
,13.65
,13.01
,13.65
,13.51
,14.09
,15.08
,14.29
,15.15
,16.00
,16.22
,15.50
,13.11
,13.66
,14.64
,14.73
,14.13
,14.18
,13.77
,14.48
,14.00
,12.62
,12.03
,10.62
,9.98
,9.88
,9.64
,9.91
,9.84
,9.76
,9.66
,10.32
,10.90
,11.30
,11.07
,10.87
,10.96
,11.13
,10.93
,11.05
,11.59
,11.98
,12.75
,13.18
,13.08
,12.50
,12.34
,11.85
,10.90
,10.56
,10.43
,10.55
,11.05
,10.49
,9.75
,9.05
,9.18
,9.31
,9.37
,9.25
,8.88
,8.40
,8.41
,8.10
,7.30
,6.86
,7.27
,7.41
,6.86
,6.49
,6.62
,6.56
,6.46
,6.43
,6.41
,6.56
,6.58
,7.32
,8.02
,7.82
,7.74
,8.03
,8.67
,8.75
,7.99
,8.13
,7.87
,7.38
,7.50
,7.83
,8.24
,8.22
,8.44
,8.77
,8.57
,8.43
,8.72
,9.11
,9.20
,9.32
,9.61
,9.40
,8.98
,8.37
,7.83
,8.13
,8.26
,8.02
,7.80
,7.77
,8.13
,8.39
,8.63
,8.78
,8.69
,8.40
,8.26
,8.22
,8.27
,8.07
,7.74
,7.47
,7.38
,7.08
,7.35
,7.23
,7.12
,7.39
,7.38
,6.80
,6.50
,6.23
,5.90
,5.39
,5.40
,5.72
,6.18
,5.93
,5.81
,5.60
,4.91
,4.72
,4.42
,4.64
,5.14
,5.21
,4.93
,4.58
,4.40
,4.30
,4.40
,4.53
,4.43
,4.36
,4.17
,4.18
,4.50
,4.54
,4.48
,4.83
,5.40
,5.99
,6.34
,6.27
,6.48
,6.50
,6.69
,7.04
,7.44
,7.71
,7.66
,7.25
,6.89
,6.68
,6.27
,5.80
,5.89
,6.10
,5.89
,5.77
,5.57
,5.39
,5.20
,5.14
,5.79
,6.11
,6.27
,6.49
,6.45
,6.21
,6.41
,6.08
,5.82
,5.91
,6.16
,6.03
,6.38
,6.61
,6.42
,6.24
,6.00
,6.06
,5.98
,5.84
,5.76
,5.74
,5.38
,5.43
,5.57
,5.58
,5.61
,5.52
,5.47
,5.24
,4.62
,4.18
,4.57
,4.48
,4.61
,4.90
,5.11
,5.03
,5.33
,5.70
,5.62
,5.77
,5.75),
start=c(1953,4), end=c(1999,9), frequency=12)
tcm5y <- ts(c(
 2.62
,2.87
,2.94
,2.75
,2.80
,2.71
,2.43
,2.42
,2.32
,2.17
,2.04
,1.93
,1.87
,1.92
,1.92
,1.85
,1.90
,1.96
,2.02
,2.09
,2.16
,2.32
,2.38
,2.48
,2.55
,2.56
,2.59
,2.72
,2.86
,2.85
,2.76
,2.81
,2.93
,2.84
,2.74
,2.93
,3.20
,3.08
,2.97
,3.12
,3.41
,3.47
,3.40
,3.56
,3.70
,3.47
,3.39
,3.46
,3.53
,3.64
,3.83
,4.00
,4.00
,4.03
,4.08
,3.72
,3.08
,2.88
,2.78
,2.64
,2.46
,2.41
,2.46
,2.77
,3.29
,3.69
,3.78
,3.70
,3.82
,4.01
,3.96
,3.99
,4.12
,4.35
,4.50
,4.58
,4.57
,4.90
,4.72
,4.75
,5.01
,4.92
,4.69
,4.31
,4.29
,4.49
,4.12
,3.79
,3.62
,3.61
,3.76
,3.81
,3.67
,3.67
,3.66
,3.60
,3.57
,3.47
,3.81
,3.84
,3.96
,3.90
,3.80
,3.82
,3.91
,3.94
,3.89
,3.68
,3.60
,3.66
,3.64
,3.80
,3.71
,3.70
,3.64
,3.60
,3.56
,3.58
,3.66
,3.68
,3.74
,3.72
,3.81
,3.89
,3.89
,3.96
,3.97
,4.01
,4.04
,4.07
,4.03
,4.14
,4.15
,4.05
,4.02
,4.03
,4.05
,4.08
,4.07
,4.04
,4.09
,4.10
,4.15
,4.15
,4.15
,4.15
,4.15
,4.15
,4.20
,4.25
,4.34
,4.46
,4.72
,4.86
,4.98
,4.92
,4.83
,4.89
,4.97
,5.17
,5.50
,5.50
,5.27
,5.36
,5.00
,4.70
,4.74
,4.54
,4.51
,4.75
,5.01
,5.23
,5.31
,5.40
,5.57
,5.78
,5.75
,5.54
,5.59
,5.76
,5.69
,6.04
,5.85
,5.60
,5.50
,5.48
,5.55
,5.66
,6.12
,6.25
,6.34
,6.41
,6.30
,6.54
,6.75
,7.01
,7.03
,7.57
,7.51
,7.53
,7.96
,8.17
,7.82
,7.21
,7.50
,7.97
,7.85
,7.59
,7.57
,7.29
,7.12
,6.47
,5.95
,5.89
,5.56
,5.00
,5.65
,6.28
,6.53
,6.85
,6.55
,6.14
,5.93
,5.78
,5.69
,5.59
,5.69
,5.87
,6.17
,5.85
,5.91
,5.97
,6.02
,6.25
,6.18
,6.12
,6.16
,6.34
,6.60
,6.80
,6.67
,6.80
,6.69
,7.33
,7.63
,7.05
,6.77
,6.92
,6.80
,6.95
,6.82
,7.31
,7.92
,8.18
,8.10
,8.38
,8.63
,8.37
,7.97
,7.68
,7.31
,7.41
,7.11
,7.30
,7.99
,7.72
,7.51
,7.92
,8.33
,8.37
,7.97
,7.80
,7.76
,7.46
,7.45
,7.49
,7.25
,7.59
,7.61
,7.49
,7.31
,7.13
,6.75
,6.52
,6.10
,6.58
,6.83
,6.93
,6.79
,6.94
,6.76
,6.84
,7.03
,7.04
,7.32
,7.34
,7.48
,7.77
,7.83
,7.86
,7.98
,8.18
,8.36
,8.54
,8.33
,8.43
,8.61
,8.84
,9.08
,9.20
,9.13
,9.20
,9.25
,9.24
,8.85
,8.90
,9.06
,9.41
,10.63
,10.93
,10.42
,10.74
,12.60
,13.47
,11.84
,9.95
,9.21
,9.53
,10.84
,11.62
,11.86
,12.83
,13.25
,12.77
,13.41
,13.41
,13.99
,14.63
,13.95
,14.79
,15.56
,15.93
,15.41
,13.38
,13.60
,14.65
,14.54
,13.98
,14.00
,13.75
,14.43
,14.07
,13.00
,12.25
,10.80
,10.38
,10.22
,10.03
,10.26
,10.08
,10.02
,10.03
,10.63
,11.21
,11.63
,11.43
,11.28
,11.41
,11.54
,11.37
,11.54
,12.02
,12.37
,13.17
,13.48
,13.27
,12.68
,12.53
,12.06
,11.33
,11.07
,10.93
,11.13
,11.52
,11.01
,10.34
,9.60
,9.70
,9.81
,9.81
,9.69
,9.28
,8.73
,8.68
,8.34
,7.46
,7.05
,7.52
,7.64
,7.06
,6.80
,6.92
,6.83
,6.76
,6.67
,6.64
,6.79
,6.79
,7.57
,8.26
,8.02
,8.01
,8.32
,8.94
,9.08
,8.35
,8.45
,8.18
,7.71
,7.83
,8.19
,8.58
,8.49
,8.66
,8.94
,8.69
,8.51
,8.79
,9.09
,9.15
,9.27
,9.51
,9.30
,8.91
,8.29
,7.83
,8.09
,8.17
,7.97
,7.81
,7.75
,8.12
,8.42
,8.60
,8.77
,8.74
,8.43
,8.33
,8.44
,8.51
,8.33
,8.02
,7.73
,7.70
,7.47
,7.77
,7.70
,7.70
,7.94
,7.91
,7.43
,7.14
,6.87
,6.62
,6.19
,6.24
,6.58
,6.95
,6.78
,6.69
,6.48
,5.84
,5.60
,5.38
,5.60
,6.04
,6.08
,5.83
,5.43
,5.19
,5.13
,5.20
,5.22
,5.09
,5.03
,4.73
,4.71
,5.06
,5.15
,5.09
,5.40
,5.94
,6.52
,6.78
,6.70
,6.91
,6.88
,7.08
,7.40
,7.72
,7.78
,7.76
,7.37
,7.05
,6.86
,6.41
,5.93
,6.01
,6.24
,6.00
,5.86
,5.69
,5.51
,5.36
,5.38
,5.97
,6.30
,6.48
,6.69
,6.64
,6.39
,6.60
,6.27
,5.97
,6.07
,6.33
,6.20
,6.54
,6.76
,6.57
,6.38
,6.12
,6.16
,6.11
,5.93
,5.80
,5.77
,5.42
,5.49
,5.61
,5.61
,5.63
,5.52
,5.46
,5.27
,4.62
,4.18
,4.54
,4.45
,4.60
,4.91
,5.14
,5.08
,5.44
,5.81
,5.68
,5.84
,5.80),
start=c(1953,4), end=c(1999,9), frequency=12)            
tcm10y <- ts(c(   
 2.83
,3.05
,3.11
,2.93
,2.95
,2.87
,2.66
,2.68
,2.59
,2.48
,2.47
,2.37
,2.29
,2.37
,2.38
,2.30
,2.36
,2.38
,2.43
,2.48
,2.51
,2.61
,2.65
,2.68
,2.75
,2.76
,2.78
,2.90
,2.97
,2.97
,2.88
,2.89
,2.96
,2.90
,2.84
,2.96
,3.18
,3.07
,3.00
,3.11
,3.33
,3.38
,3.34
,3.49
,3.59
,3.46
,3.34
,3.41
,3.48
,3.60
,3.80
,3.93
,3.93
,3.92
,3.97
,3.72
,3.21
,3.09
,3.05
,2.98
,2.88
,2.92
,2.97
,3.20
,3.54
,3.76
,3.80
,3.74
,3.86
,4.02
,3.96
,3.99
,4.12
,4.31
,4.34
,4.40
,4.43
,4.68
,4.53
,4.53
,4.69
,4.72
,4.49
,4.25
,4.28
,4.35
,4.15
,3.90
,3.80
,3.80
,3.89
,3.93
,3.84
,3.84
,3.78
,3.74
,3.78
,3.71
,3.88
,3.92
,4.04
,3.98
,3.92
,3.94
,4.06
,4.08
,4.04
,3.93
,3.84
,3.87
,3.91
,4.01
,3.98
,3.98
,3.93
,3.92
,3.86
,3.83
,3.92
,3.93
,3.97
,3.93
,3.99
,4.02
,4.00
,4.08
,4.11
,4.12
,4.13
,4.17
,4.15
,4.22
,4.23
,4.20
,4.17
,4.19
,4.19
,4.20
,4.19
,4.15
,4.18
,4.19
,4.21
,4.21
,4.20
,4.21
,4.21
,4.20
,4.25
,4.29
,4.35
,4.45
,4.62
,4.61
,4.83
,4.87
,4.75
,4.78
,4.81
,5.02
,5.22
,5.18
,5.01
,5.16
,4.84
,4.58
,4.63
,4.54
,4.59
,4.85
,5.02
,5.16
,5.28
,5.30
,5.48
,5.75
,5.70
,5.53
,5.56
,5.74
,5.64
,5.87
,5.72
,5.50
,5.42
,5.46
,5.58
,5.70
,6.03
,6.04
,6.19
,6.30
,6.17
,6.32
,6.57
,6.72
,6.69
,7.16
,7.10
,7.14
,7.65
,7.79
,7.24
,7.07
,7.39
,7.91
,7.84
,7.46
,7.53
,7.39
,7.33
,6.84
,6.39
,6.24
,6.11
,5.70
,5.83
,6.39
,6.52
,6.73
,6.58
,6.14
,5.93
,5.81
,5.93
,5.95
,6.08
,6.07
,6.19
,6.13
,6.11
,6.11
,6.21
,6.55
,6.48
,6.28
,6.36
,6.46
,6.64
,6.71
,6.67
,6.85
,6.90
,7.13
,7.40
,7.09
,6.79
,6.73
,6.74
,6.99
,6.96
,7.21
,7.51
,7.58
,7.54
,7.81
,8.04
,8.04
,7.90
,7.68
,7.43
,7.50
,7.39
,7.73
,8.23
,8.06
,7.86
,8.06
,8.40
,8.43
,8.14
,8.05
,8.00
,7.74
,7.79
,7.73
,7.56
,7.90
,7.86
,7.83
,7.77
,7.59
,7.41
,7.29
,6.87
,7.21
,7.39
,7.46
,7.37
,7.46
,7.28
,7.33
,7.40
,7.34
,7.52
,7.58
,7.69
,7.96
,8.03
,8.04
,8.15
,8.35
,8.46
,8.64
,8.41
,8.42
,8.64
,8.81
,9.01
,9.10
,9.10
,9.12
,9.18
,9.25
,8.91
,8.95
,9.03
,9.33
,10.30
,10.65
,10.39
,10.80
,12.41
,12.75
,11.47
,10.18
,9.78
,10.25
,11.10
,11.51
,11.75
,12.68
,12.84
,12.57
,13.19
,13.12
,13.68
,14.10
,13.47
,14.28
,14.94
,15.32
,15.15
,13.39
,13.72
,14.59
,14.43
,13.86
,13.87
,13.62
,14.30
,13.95
,13.06
,12.34
,10.91
,10.55
,10.54
,10.46
,10.72
,10.51
,10.40
,10.38
,10.85
,11.38
,11.85
,11.65
,11.54
,11.69
,11.83
,11.67
,11.84
,12.32
,12.63
,13.41
,13.56
,13.36
,12.72
,12.52
,12.16
,11.57
,11.50
,11.38
,11.51
,11.86
,11.43
,10.85
,10.16
,10.31
,10.33
,10.37
,10.24
,9.78
,9.26
,9.19
,8.70
,7.78
,7.30
,7.71
,7.80
,7.30
,7.17
,7.45
,7.43
,7.25
,7.11
,7.08
,7.25
,7.25
,8.02
,8.61
,8.40
,8.45
,8.76
,9.42
,9.52
,8.86
,8.99
,8.67
,8.21
,8.37
,8.72
,9.09
,8.92
,9.06
,9.26
,8.98
,8.80
,8.96
,9.11
,9.09
,9.17
,9.36
,9.18
,8.86
,8.28
,8.02
,8.11
,8.19
,8.01
,7.87
,7.84
,8.21
,8.47
,8.59
,8.79
,8.76
,8.48
,8.47
,8.75
,8.89
,8.72
,8.39
,8.08
,8.09
,7.85
,8.11
,8.04
,8.07
,8.28
,8.27
,7.90
,7.65
,7.53
,7.42
,7.09
,7.03
,7.34
,7.54
,7.48
,7.39
,7.26
,6.84
,6.59
,6.42
,6.59
,6.87
,6.77
,6.60
,6.26
,5.98
,5.97
,6.04
,5.96
,5.81
,5.68
,5.36
,5.33
,5.72
,5.77
,5.75
,5.97
,6.48
,6.97
,7.18
,7.10
,7.30
,7.24
,7.46
,7.74
,7.96
,7.81
,7.78
,7.47
,7.20
,7.06
,6.63
,6.17
,6.28
,6.49
,6.20
,6.04
,5.93
,5.71
,5.65
,5.81
,6.27
,6.51
,6.74
,6.91
,6.87
,6.64
,6.83
,6.53
,6.20
,6.30
,6.58
,6.42
,6.69
,6.89
,6.71
,6.49
,6.22
,6.30
,6.21
,6.03
,5.88
,5.81
,5.54
,5.57
,5.65
,5.64
,5.65
,5.50
,5.46
,5.34
,4.81
,4.53
,4.83
,4.65
,4.72
,5.00
,5.23
,5.18
,5.54
,5.90
,5.79
,5.94
,5.92),
start=c(1953,4), end=c(1999,9), frequency=12)
tcm <- ts.union (tcm1y, tcm3y, tcm5y, tcm10y)
